## Arches Controlled Lists 1.0.0 Release Notes

### Bug Fixes and Enhancements

- Fix issue with migrating complex polyhierarchies from the RDM [#190](https://github.com/archesproject/arches-controlled-lists/issues/190)
- Use concept identifiers as URIs during RDM to Controlled Lists migration [#96](https://github.com/archesproject/arches-controlled-lists/issues/96)
- Fix reference datatype label lookup for multiple labels and labels with commas [#189](https://github.com/archesproject/arches-controlled-lists/issues/189)